==> huaweicloudsdkdrs-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/show_actions_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowActionsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'job_action': 'JobActions'
    }

    attribute_map = {
        'job_action': 'job_action'
    }

    def __init__(self, job_action=None):
        """ShowActionsResponse

        The model defined in huaweicloud sdk

        :param job_action: 
        :type job_action: :class:`huaweicloudsdkdrs.v5.JobActions`
        """
        
        super(ShowActionsResponse, self).__init__()

        self._job_action = None
        self.discriminator = None

        if job_action is not None:
            self.job_action = job_action

    @property
    def job_action(self):
        """Gets the job_action of this ShowActionsResponse.

        :return: The job_action of this ShowActionsResponse.
        :rtype: :class:`huaweicloudsdkdrs.v5.JobActions`
        """
        return self._job_action

    @job_action.setter
    def job_action(self, job_action):
        """Sets the job_action of this ShowActionsResponse.

        :param job_action: The job_action of this ShowActionsResponse.
        :type job_action: :class:`huaweicloudsdkdrs.v5.JobActions`
        """
        self._job_action = job_action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowActionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.146-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/show_actions_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowActionsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'job_action': 'JobActions'
    }

    attribute_map = {
        'job_action': 'job_action'
    }

    def __init__(self, job_action=None):
        r"""ShowActionsResponse

        The model defined in huaweicloud sdk

        :param job_action: 
        :type job_action: :class:`huaweicloudsdkdrs.v5.JobActions`
        """
        
        super(ShowActionsResponse, self).__init__()

        self._job_action = None
        self.discriminator = None

        if job_action is not None:
            self.job_action = job_action

    @property
    def job_action(self):
        r"""Gets the job_action of this ShowActionsResponse.

        :return: The job_action of this ShowActionsResponse.
        :rtype: :class:`huaweicloudsdkdrs.v5.JobActions`
        """
        return self._job_action

    @job_action.setter
    def job_action(self, job_action):
        r"""Sets the job_action of this ShowActionsResponse.

        :param job_action: The job_action of this ShowActionsResponse.
        :type job_action: :class:`huaweicloudsdkdrs.v5.JobActions`
        """
        self._job_action = job_action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowActionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
